[Libreoffice-commits] core.git: filter/source fpicker/source framework/inc framework/qa framework/source include/comphelper include/framework odk/examples sd/inc sfx2/source svx/source vcl/source

Julien Nabet serval2412 at yahoo.fr
Sun Feb 9 01:13:03 PST 2014


 filter/source/config/cache/contenthandlerfactory.hxx                          |    2 +-
 filter/source/config/cache/filtercache.hxx                                    |    2 +-
 filter/source/config/cache/filterfactory.hxx                                  |    2 +-
 filter/source/config/cache/frameloaderfactory.hxx                             |    2 +-
 filter/source/config/cache/typedetection.hxx                                  |    2 +-
 fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx               |    8 ++++----
 fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx                       |    8 ++++----
 fpicker/source/win32/filepicker/asyncrequests.hxx                             |    2 +-
 framework/inc/dispatch/closedispatcher.hxx                                    |    8 ++++----
 framework/inc/dispatch/dispatchprovider.hxx                                   |    2 +-
 framework/inc/dispatch/startmoduledispatcher.hxx                              |    2 +-
 framework/inc/helper/statusindicatorfactory.hxx                               |    2 +-
 framework/inc/interaction/quietinteraction.hxx                                |    2 +-
 framework/inc/recording/dispatchrecordersupplier.hxx                          |    2 +-
 framework/inc/services/desktop.hxx                                            |    2 +-
 framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java              |    2 +-
 framework/source/accelerators/documentacceleratorconfiguration.cxx            |    2 +-
 framework/source/accelerators/globalacceleratorconfiguration.cxx              |    2 +-
 framework/source/accelerators/moduleacceleratorconfiguration.cxx              |    2 +-
 framework/source/dispatch/mailtodispatcher.cxx                                |    2 +-
 framework/source/fwe/helper/titlehelper.cxx                                   |    6 +++---
 framework/source/inc/accelerators/acceleratorconfiguration.hxx                |    2 +-
 framework/source/inc/accelerators/presethandler.hxx                           |    8 ++++----
 framework/source/inc/loadenv/loadenv.hxx                                      |    4 ++--
 framework/source/jobs/jobresult.cxx                                           |    4 ++--
 framework/source/recording/dispatchrecordersupplier.cxx                       |    2 +-
 framework/source/services/autorecovery.cxx                                    |    8 ++++----
 framework/source/services/frame.cxx                                           |    2 +-
 framework/source/services/modulemanager.cxx                                   |    2 +-
 framework/source/services/pathsettings.cxx                                    |    2 +-
 include/comphelper/numberedcollection.hxx                                     |    2 +-
 include/comphelper/sequenceashashmap.hxx                                      |    2 +-
 include/framework/preventduplicateinteraction.hxx                             |    4 ++--
 include/framework/titlehelper.hxx                                             |    4 ++--
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java |    2 +-
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java     |    2 +-
 sd/inc/Outliner.hxx                                                           |    2 +-
 sfx2/source/appl/sfxhelp.cxx                                                  |    2 +-
 sfx2/source/dialog/backingcomp.cxx                                            |    2 +-
 svx/source/inc/svxrectctaccessiblecontext.hxx                                 |    4 ++--
 svx/source/unodraw/recoveryui.cxx                                             |    2 +-
 vcl/source/window/window.cxx                                                  |    2 +-
 42 files changed, 64 insertions(+), 64 deletions(-)

New commits:
commit 94bc29cb71d08ebe039d5ce5b6b2762ac24cbb8f
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Sun Feb 9 10:12:07 2014 +0100

    Typo: I/internaly -> I/internally
    
    Change-Id: Ic9056baf58698743492ab57a882341c730ef2f7a

diff --git a/filter/source/config/cache/contenthandlerfactory.hxx b/filter/source/config/cache/contenthandlerfactory.hxx
index aaf300c..9cb44e4 100644
--- a/filter/source/config/cache/contenthandlerfactory.hxx
+++ b/filter/source/config/cache/contenthandlerfactory.hxx
@@ -120,7 +120,7 @@ class ContentHandlerFactory : public ::cppu::ImplInheritanceHelper1< BaseContain
             @param  xSMGR
                     reference to the uno service manager, which require
                     this new instance. It should be passed to the new object
-                    so it can be used internaly to create own needed uno resources.
+                    so it can be used internally to create own needed uno resources.
 
             @return The new instance of this service as an uno reference.
          */
diff --git a/filter/source/config/cache/filtercache.hxx b/filter/source/config/cache/filtercache.hxx
index b5550c3..a3e408f 100644
--- a/filter/source/config/cache/filtercache.hxx
+++ b/filter/source/config/cache/filtercache.hxx
@@ -546,7 +546,7 @@ class FilterCache : public BaseLock
 
             @attention  These properties are not part of the normal CacheItem
                         returned by the method getItem(). Because getItem() is
-                        used internaly too but these specialized properties
+                        used internally too but these specialized properties
                         are needed at our container services only. So these
                         function sets are different to allow different handling.
 
diff --git a/filter/source/config/cache/filterfactory.hxx b/filter/source/config/cache/filterfactory.hxx
index befb205..63f8368 100644
--- a/filter/source/config/cache/filterfactory.hxx
+++ b/filter/source/config/cache/filterfactory.hxx
@@ -184,7 +184,7 @@ class FilterFactory : public ::cppu::ImplInheritanceHelper1< BaseContainer
             @param  xSMGR
                     reference to the uno service manager, which require
                     this new instance. It should be passed to the new object
-                    so it can be used internaly to create own needed uno resources.
+                    so it can be used internally to create own needed uno resources.
 
             @return The new instance of this service as an uno reference.
          */
diff --git a/filter/source/config/cache/frameloaderfactory.hxx b/filter/source/config/cache/frameloaderfactory.hxx
index dcf7135..21ffba4 100644
--- a/filter/source/config/cache/frameloaderfactory.hxx
+++ b/filter/source/config/cache/frameloaderfactory.hxx
@@ -120,7 +120,7 @@ class FrameLoaderFactory : public ::cppu::ImplInheritanceHelper1< BaseContainer
             @param  xSMGR
                     reference to the uno service manager, which require
                     this new instance. It should be passed to the new object
-                    so it can be used internaly to create own needed uno resources.
+                    so it can be used internally to create own needed uno resources.
 
             @return The new instance of this service as an uno reference.
          */
diff --git a/filter/source/config/cache/typedetection.hxx b/filter/source/config/cache/typedetection.hxx
index 6875a17..62e6719 100644
--- a/filter/source/config/cache/typedetection.hxx
+++ b/filter/source/config/cache/typedetection.hxx
@@ -372,7 +372,7 @@ public:
         @param  xSMGR
                 reference to the uno service manager, which require
                 this new instance. It should be passed to the new object
-                so it can be used internaly to create own needed uno resources.
+                so it can be used internally to create own needed uno resources.
 
         @return The new instance of this service as an uno reference.
      */
diff --git a/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx b/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx
index fd52d97..883ff34 100644
--- a/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx
+++ b/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx
@@ -130,7 +130,7 @@ class VistaFilePickerEventHandler : public ::cppu::BaseMutex
         //------------------------------------------------------------------------------------
         /** start listening for file picker events on the given file open dialog COM object.
          *
-         *  The broadcaster will be cached internaly so deregistration will be easy.
+         *  The broadcaster will be cached internally so deregistration will be easy.
          *  Further all needed information are capsulated within this class (e.g. the listener handler).
          *  Nobody outside must know such information.
          *
@@ -143,10 +143,10 @@ class VistaFilePickerEventHandler : public ::cppu::BaseMutex
         void startListening( const TFileDialog& pBroadcaster );
 
         //------------------------------------------------------------------------------------
-        /** stop listening for file picker events on the internaly cached dialog COM object.
+        /** stop listening for file picker events on the internally cached dialog COM object.
          *
-         *  The  COM dialog provided on the startListeneing() call was cached internaly.
-         *  And now its used to deregister this listener. Doing so the also internaly cached
+         *  The  COM dialog provided on the startListeneing() call was cached internally.
+         *  And now its used to deregister this listener. Doing so the also internally cached
          *  listener handle is used. If listener was not already registered - nothing will happen.
          */
         void stopListening();
diff --git a/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx b/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx
index a6a38bb..0bf0d88 100644
--- a/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx
+++ b/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx
@@ -97,7 +97,7 @@ static const OUString STRING_SEPARATOR("----------------------------------------
 
 //-----------------------------------------------------------------------------
 /** native implementation of the file picker on Vista and upcoming windows versions.
- *  This dialog uses COM internaly. Further it marshall every request so it will
+ *  This dialog uses COM internally. Further it marshall every request so it will
  *  be executed within it's own STA thread !
  */
 //-----------------------------------------------------------------------------
@@ -266,10 +266,10 @@ class VistaFilePickerImpl : private ::cppu::BaseMutex
         void impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_Int32 nTemplate);
 
         //---------------------------------------------------------------------
-        /** returns an interface, which can be used to customize the internaly used
+        /** returns an interface, which can be used to customize the internally used
          *  COM dialog.
          *
-         *  Because we use two member (open/save dialog) internaly, this method
+         *  Because we use two member (open/save dialog) internally, this method
          *  ask the current active one for it's customization interface.
          *
          *  @return the customization interface for the current used dialog.
@@ -305,7 +305,7 @@ class VistaFilePickerImpl : private ::cppu::BaseMutex
         //---------------------------------------------------------------------
         /** cache last selected list of files
          *  Because those list must be retrieved directly after closing the dialog
-         *  (and only in case it was finished successfully) we cache it internaly.
+         *  (and only in case it was finished successfully) we cache it internally.
          *  Because the outside provided UNO API decouple showing the dialog
          *  and asking for results .-)
          */
diff --git a/fpicker/source/win32/filepicker/asyncrequests.hxx b/fpicker/source/win32/filepicker/asyncrequests.hxx
index 6653a6c..ae9a570 100644
--- a/fpicker/source/win32/filepicker/asyncrequests.hxx
+++ b/fpicker/source/win32/filepicker/asyncrequests.hxx
@@ -186,7 +186,7 @@ class AsyncRequests : private ::cppu::BaseMutex
 
         //---------------------------------------------------------------------
         /** our STA .-)
-         *  Will run between start() & finish(). Internaly it runs a loop ...
+         *  Will run between start() & finish(). Internally it runs a loop ...
          *  waiting for requests. Every request will be executed synchronously
          *  in blocked mode.
          */
diff --git a/framework/inc/dispatch/dispatchprovider.hxx b/framework/inc/dispatch/dispatchprovider.hxx
index 6c6e928..53ad483 100644
--- a/framework/inc/dispatch/dispatchprovider.hxx
+++ b/framework/inc/dispatch/dispatchprovider.hxx
@@ -44,7 +44,7 @@ namespace framework{
 
 /**
     @descr          We know some special dispatch objects with different functionality.
-                    The can be created internaly by the following DispatchProvider.
+                    The can be created internally by the following DispatchProvider.
                     Here we define some identifier to force creation of the right one.
 */
 enum EDispatchHelper
diff --git a/framework/inc/dispatch/startmoduledispatcher.hxx b/framework/inc/dispatch/startmoduledispatcher.hxx
index e5bbeb8..bb6f634 100644
--- a/framework/inc/dispatch/startmoduledispatcher.hxx
+++ b/framework/inc/dispatch/startmoduledispatcher.hxx
@@ -89,7 +89,7 @@ class StartModuleDispatcher : // baseclasses ... order is necessary for right in
 
             @param  xContext
                     an UNO service manager, which is needed to create UNO resource
-                    internaly.
+                    internally.
 
             @param  xFrame
                     the frame where the corresponding dispatch was started.
diff --git a/framework/inc/helper/statusindicatorfactory.hxx b/framework/inc/helper/statusindicatorfactory.hxx
index 4d8b486..f97cadb 100644
--- a/framework/inc/helper/statusindicatorfactory.hxx
+++ b/framework/inc/helper/statusindicatorfactory.hxx
@@ -138,7 +138,7 @@ typedef ::std::vector< IndicatorInfo > IndicatorStack;
 //===============================================
 /** @short          implement a factory service to create new status indicator objects
 
-    @descr          Internaly it uses:
+    @descr          Internally it uses:
                     - a vcl based
                     - or an uno based and by the frame layouted
                     progress implementation.
diff --git a/framework/inc/interaction/quietinteraction.hxx b/framework/inc/interaction/quietinteraction.hxx
index 69da3a3..93cc62a 100644
--- a/framework/inc/interaction/quietinteraction.hxx
+++ b/framework/inc/interaction/quietinteraction.hxx
@@ -89,7 +89,7 @@ class QuietInteraction : private ThreadHelpBase
 
         /**
             @short      return the handled interaction request
-            @descr      We saved any getted interaction request internaly.
+            @descr      We saved any getted interaction request internally.
                         May the outside user of this class is interessted
                         on that. Especialy we gotted an unknown interaction
                         and aborted it hard.
diff --git a/framework/inc/recording/dispatchrecordersupplier.hxx b/framework/inc/recording/dispatchrecordersupplier.hxx
index 9fbf140..a7a88f5 100644
--- a/framework/inc/recording/dispatchrecordersupplier.hxx
+++ b/framework/inc/recording/dispatchrecordersupplier.hxx
@@ -62,7 +62,7 @@ class DispatchRecorderSupplier  :   // baseclasses
         /** provided dispatch recorder of this supplier instance
 
             @life   Is controled from outside. Because this variable is setted
-                    from there and not created internaly. But we release our
+                    from there and not created internally. But we release our
                     reference to it if we die.
          */
         css::uno::Reference< css::frame::XDispatchRecorder > m_xDispatchRecorder;
diff --git a/framework/inc/services/desktop.hxx b/framework/inc/services/desktop.hxx
index 42d8b9f..de5121a 100644
--- a/framework/inc/services/desktop.hxx
+++ b/framework/inc/services/desktop.hxx
@@ -452,7 +452,7 @@ class Desktop   :   // base classes
 
         //---------------------------------------------------------------------
         /** special terminate listener which loads images asynchronous for current open documents.
-          * Because internaly it uses blocking system APIs ... it cant be guaranteed that
+          * Because internally it uses blocking system APIs ... it cant be guaranteed that
           * running jobs can be cancelled successfully if the corressponding document will be closed ...
           * it will not hinder those documents on closing. Instead it let all jobs running ...
           * but at least on terminate we have to wait for all those blocked requests.
diff --git a/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java b/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
index c7d4f35..b6ae2a1 100644
--- a/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
+++ b/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
@@ -279,7 +279,7 @@ public class CheckXComponentLoader
             {
                 loadURL(m_xLoader, RESULT_VALID_DOC, sURL, "_blank", 0, lProps);
                 // Its not needed to reset this using states!
-                // Its done internaly ...
+                // Its done internally ...
                 if (!xIndicator.wasUsed())
                 {
                     System.out.println("External progress was not used for loading.");
diff --git a/framework/source/accelerators/documentacceleratorconfiguration.cxx b/framework/source/accelerators/documentacceleratorconfiguration.cxx
index 8019e81..bf58b4c 100644
--- a/framework/source/accelerators/documentacceleratorconfiguration.cxx
+++ b/framework/source/accelerators/documentacceleratorconfiguration.cxx
@@ -65,7 +65,7 @@ public:
     /** initialize this instance and fill the internal cache.
 
         @param  xSMGR
-                reference to an uno service manager, which is used internaly.
+                reference to an uno service manager, which is used internally.
      */
     DocumentAcceleratorConfiguration(
             const css::uno::Reference< css::uno::XComponentContext >& xContext,
diff --git a/framework/source/accelerators/globalacceleratorconfiguration.cxx b/framework/source/accelerators/globalacceleratorconfiguration.cxx
index 3b809ee..72f4234 100644
--- a/framework/source/accelerators/globalacceleratorconfiguration.cxx
+++ b/framework/source/accelerators/globalacceleratorconfiguration.cxx
@@ -51,7 +51,7 @@ public:
     /** initialize this instance and fill the internal cache.
 
         @param  xSMGR
-                reference to an uno service manager, which is used internaly.
+                reference to an uno service manager, which is used internally.
      */
     GlobalAcceleratorConfiguration(const css::uno::Reference< css::uno::XComponentContext >& xContext);
 
diff --git a/framework/source/accelerators/moduleacceleratorconfiguration.cxx b/framework/source/accelerators/moduleacceleratorconfiguration.cxx
index 7648c27..e507b41 100644
--- a/framework/source/accelerators/moduleacceleratorconfiguration.cxx
+++ b/framework/source/accelerators/moduleacceleratorconfiguration.cxx
@@ -65,7 +65,7 @@ public:
     /** initialize this instance and fill the internal cache.
 
         @param  xSMGR
-                reference to an uno service manager, which is used internaly.
+                reference to an uno service manager, which is used internally.
      */
     ModuleAcceleratorConfiguration(
             const css::uno::Reference< css::uno::XComponentContext >& xContext,
diff --git a/framework/source/dispatch/mailtodispatcher.cxx b/framework/source/dispatch/mailtodispatcher.cxx
index 8f3b285..1b51d5c 100644
--- a/framework/source/dispatch/mailtodispatcher.cxx
+++ b/framework/source/dispatch/mailtodispatcher.cxx
@@ -123,7 +123,7 @@ css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL Mail
     @short      dispatch URL with arguments
     @descr      We use threadsafe internal method to do so. It returns a state value - but we ignore it.
                 Because we don't support status listener notifications here. Status events are not guaranteed -
-                and we call another service internaly which doesn't return any notifications too.
+                and we call another service internally which doesn't return any notifications too.
 
     @param      aURL
                     mail URL which should be executed
diff --git a/framework/source/fwe/helper/titlehelper.cxx b/framework/source/fwe/helper/titlehelper.cxx
index e19a679..b02549d 100644
--- a/framework/source/fwe/helper/titlehelper.cxx
+++ b/framework/source/fwe/helper/titlehelper.cxx
@@ -330,7 +330,7 @@ void TitleHelper::impl_updateTitleForModel (const css::uno::Reference< css::fram
     // SYNCHRONIZED ->
     ::osl::ResettableMutexGuard aLock(m_aMutex);
 
-        // external title wont be updated internaly !
+        // external title wont be updated internally !
         // It has to be set from outside new.
         if (m_bExternalTitle)
             return;
@@ -401,7 +401,7 @@ void TitleHelper::impl_updateTitleForController (const css::uno::Reference< css:
     // SYNCHRONIZED ->
     ::osl::ResettableMutexGuard aLock(m_aMutex);
 
-        // external title wont be updated internaly !
+        // external title wont be updated internally !
         // It has to be set from outside new.
         if (m_bExternalTitle)
             return;
@@ -470,7 +470,7 @@ void TitleHelper::impl_updateTitleForFrame (const css::uno::Reference< css::fram
     // SYNCHRONIZED ->
     ::osl::ResettableMutexGuard aLock(m_aMutex);
 
-        // external title wont be updated internaly !
+        // external title wont be updated internally !
         // It has to be set from outside new.
         if (m_bExternalTitle)
             return;
diff --git a/framework/source/inc/accelerators/acceleratorconfiguration.hxx b/framework/source/inc/accelerators/acceleratorconfiguration.hxx
index 93388d3..4e4d6b9 100644
--- a/framework/source/inc/accelerators/acceleratorconfiguration.hxx
+++ b/framework/source/inc/accelerators/acceleratorconfiguration.hxx
@@ -263,7 +263,7 @@ class XMLBasedAcceleratorConfiguration : protected ThreadHelpBase,
         /** @short  returns a reference to one of our internal cache members.
 
         @descr  We implement the copy-on-write pattern. Doing so
-        we know two caches internaly. The second one is used
+        we know two caches internally. The second one is used
         only, if the container was changed.
 
         This method here returns access to one of these
diff --git a/framework/source/inc/loadenv/loadenv.hxx b/framework/source/inc/loadenv/loadenv.hxx
index dadef23..f6c1bd7 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -201,7 +201,7 @@ public:
     /** @short  initialize a new instance of this load environment.
 
         @param  xContext
-                reference to an uno service manager, which can be used internaly
+                reference to an uno service manager, which can be used internally
                 to create on needed services on demand.
 
         @throw  Currently there is no reason to throw such exception!
@@ -429,7 +429,7 @@ private:
         @return [string]
                 the type selected by the user.
 
-        @attention  Internaly we update the member m_lMediaDescriptor!
+        @attention  Internally we update the member m_lMediaDescriptor!
      */
     OUString impl_askUserForTypeAndFilterIfAllowed()
         throw(LoadEnvException, css::uno::RuntimeException);
diff --git a/framework/source/jobs/jobresult.cxx b/framework/source/jobs/jobresult.cxx
index d972326..f0336df 100644
--- a/framework/source/jobs/jobresult.cxx
+++ b/framework/source/jobs/jobresult.cxx
@@ -147,7 +147,7 @@ JobResult::JobResult( const JobResult& rCopy )
 //________________________________
 /**
     @short      standard dtor
-    @descr      Free all internaly used resources at the end of living.
+    @descr      Free all internally used resources at the end of living.
 */
 JobResult::~JobResult()
 {
@@ -184,7 +184,7 @@ void JobResult::operator=( const JobResult& rCopy )
                 by using our other members!
 
     @param      eParts
-                    a flag mask too, which will be compared with our internaly set one.
+                    a flag mask too, which will be compared with our internally set one.
 
     @return     We return true only, if any set flag of the given mask match.
 */
diff --git a/framework/source/recording/dispatchrecordersupplier.cxx b/framework/source/recording/dispatchrecordersupplier.cxx
index f2e4a25..4c68e81 100644
--- a/framework/source/recording/dispatchrecordersupplier.cxx
+++ b/framework/source/recording/dispatchrecordersupplier.cxx
@@ -105,7 +105,7 @@ void SAL_CALL DispatchRecorderSupplier::setDispatchRecorder( const css::uno::Ref
 /**
     @short      provides access to the dispatch recorder of this supplier
     @descr      Such recorder can be used outside to record dispatches.
-                But normaly he is used internaly only. Of course he must used
+                But normaly he is used internally only. Of course he must used
                 from outside to get the recorded data e.g. for saving it as a
                 script.
 
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 961776f..217a096 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -2667,7 +2667,7 @@ void SAL_CALL Frame::windowDeactivated( const css::lang::EventObject& aEvent ) t
 void SAL_CALL Frame::windowClosing( const css::lang::EventObject& ) throw( css::uno::RuntimeException )
 {
     /* #i62088#
-        Some interceptor objects intercept our "internaly asynchronoues implemented" dispatch call.
+        Some interceptor objects intercept our "internally asynchronoues implemented" dispatch call.
         And they close this frame directly (means synchronous then).
         Means: Frame::windowClosing()->Frame::close()
         In such situation its not a good idea to hold this transaction count alive .-)
diff --git a/framework/source/services/modulemanager.cxx b/framework/source/services/modulemanager.cxx
index 84e1c9b..572fa9f 100644
--- a/framework/source/services/modulemanager.cxx
+++ b/framework/source/services/modulemanager.cxx
@@ -462,7 +462,7 @@ OUString ModuleManager::implts_identify(const css::uno::Reference< css::uno::XIn
 {
     // Search for an optional (!) interface XModule first.
     // Its used to overrule an existing service name. Used e.g. by our database form designer
-    // which uses a writer module internaly.
+    // which uses a writer module internally.
     css::uno::Reference< css::frame::XModule > xModule(xComponent, css::uno::UNO_QUERY);
     if (xModule.is())
         return xModule->getIdentifier();
diff --git a/framework/source/services/pathsettings.cxx b/framework/source/services/pathsettings.cxx
index f551f29..c4665fb 100644
--- a/framework/source/services/pathsettings.cxx
+++ b/framework/source/services/pathsettings.cxx
@@ -119,7 +119,7 @@ class PathSettings : private osl::Mutex
             /// an internal name describing this path
             OUString sPathName;
 
-            /// contains all paths, which are used internaly - but are not visible for the user.
+            /// contains all paths, which are used internally - but are not visible for the user.
             OUStringList lInternalPaths;
 
             /// contains all paths configured by the user
diff --git a/include/comphelper/numberedcollection.hxx b/include/comphelper/numberedcollection.hxx
index 868b89d..e2c00d1 100644
--- a/include/comphelper/numberedcollection.hxx
+++ b/include/comphelper/numberedcollection.hxx
@@ -76,7 +76,7 @@ class COMPHELPER_DLLPUBLIC NumberedCollection : private ::cppu::BaseMutex
         NumberedCollection();
 
         //---------------------------------------
-        /** @short  free all internaly used resources.
+        /** @short  free all internally used resources.
          */
         virtual ~NumberedCollection();
 
diff --git a/include/comphelper/sequenceashashmap.hxx b/include/comphelper/sequenceashashmap.hxx
index f6c5c09..f33bdd5 100644
--- a/include/comphelper/sequenceashashmap.hxx
+++ b/include/comphelper/sequenceashashmap.hxx
@@ -255,7 +255,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHashMap : public SequenceAsHashMapBase
             @param  aValue
                     the new (unpacked!) value.
                     Note: This value will be transformed to an Any
-                    internaly, because only Any values can be
+                    internally, because only Any values can be
                     part of a PropertyValue or NamedValue structure.
 
             @return TRUE if this property was added as new item;
diff --git a/include/framework/preventduplicateinteraction.hxx b/include/framework/preventduplicateinteraction.hxx
index 63ff840..54be9f2 100644
--- a/include/framework/preventduplicateinteraction.hxx
+++ b/include/framework/preventduplicateinteraction.hxx
@@ -159,7 +159,7 @@ class FWE_DLLPUBLIC PreventDuplicateInteraction : private ThreadHelpBase2
                         generic UI interaction handler for later internal using.
 
             @param      xSMGR
-                            uno service manager for creating services internaly
+                            uno service manager for creating services internally
 
             @threadsafe not necessary
         */
@@ -173,7 +173,7 @@ class FWE_DLLPUBLIC PreventDuplicateInteraction : private ThreadHelpBase2
 
         //_________________________________
         /**
-            @short      set the outside interaction handler, which must be used internaly
+            @short      set the outside interaction handler, which must be used internally
                         if the interaction will not be blocked by the set list of rules.
 
             @note       This overwrites the settings of e.g. useDefaultUUIHandler()!
diff --git a/include/framework/titlehelper.hxx b/include/framework/titlehelper.hxx
index 7602572..125d3c1 100644
--- a/include/framework/titlehelper.hxx
+++ b/include/framework/titlehelper.hxx
@@ -68,7 +68,7 @@ class FWE_DLLPUBLIC TitleHelper : private ::cppu::BaseMutex
         TitleHelper(const css::uno::Reference< css::uno::XComponentContext >& rxContext);
 
         //---------------------------------------
-        /** @short  free all internaly used resources.
+        /** @short  free all internally used resources.
          */
         virtual ~TitleHelper();
 
@@ -183,7 +183,7 @@ class FWE_DLLPUBLIC TitleHelper : private ::cppu::BaseMutex
         /** provides parts of our own title and we listen there for changes too. */
         css::uno::WeakReference< css::frame::XTitle > m_xSubTitle;
 
-        /** if it's set to sal_True the member m_sTitle has not to be changed internaly.
+        /** if it's set to sal_True the member m_sTitle has not to be changed internally.
             It was set from outside and so outside code has to make sure it will be
             updated.
          */
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
index 2f41916..89980b7 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
@@ -59,7 +59,7 @@ import com.sun.star.uno.UnoRuntime;
  * Another reason for such extra class for listening:
  * Most listener callbacks are asynchronoues [oneay] requests.
  * And it's not allowed to call back synchronously there.
- * So we must start threads for updating something internaly.
+ * So we must start threads for updating something internally.
  *
  */
 class StatusListener implements com.sun.star.frame.XStatusListener,
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
index 63ae142..aad5393 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
@@ -207,7 +207,7 @@ public class StatusView extends    JPanel
      * Set new frame for this view and start listening for events imedatly.
      * We create one status listener for every control we wish to update.
      * And because the environment of the frame can be changed - these
-     * listener refresh himself internaly for frame action events too.
+     * listener refresh himself internally for frame action events too.
      * So we register it as such frame action listener only here.
      * Rest is done automaticly ...
      *
diff --git a/sd/inc/Outliner.hxx b/sd/inc/Outliner.hxx
index ebf1c7b..afd57ab 100644
--- a/sd/inc/Outliner.hxx
+++ b/sd/inc/Outliner.hxx
@@ -157,7 +157,7 @@ public:
     void StartConversion( sal_Int16 nSourceLanguage,  sal_Int16 nTargetLanguage,
                 const Font *pTargetFont, sal_Int32 nOptions, sal_Bool bIsInteractive );
 
-    /** This is called internaly when text conversion is started.
+    /** This is called internally when text conversion is started.
         The position of current view mode/page/object/caret position
         is remembered and will be restored after conversion.
     */
diff --git a/sfx2/source/appl/sfxhelp.cxx b/sfx2/source/appl/sfxhelp.cxx
index e7fd583..209de19 100644
--- a/sfx2/source/appl/sfxhelp.cxx
+++ b/sfx2/source/appl/sfxhelp.cxx
@@ -424,7 +424,7 @@ SfxHelpWindow_Impl* impl_createHelp(Reference< XFrame2 >& rHelpTask   ,
         xParentWindow->setVisible(sal_True);
         xHelpWindow->setVisible(sal_True);
 
-        // This sub frame is created internaly (if we called new SfxHelpWindow_Impl() ...)
+        // This sub frame is created internally (if we called new SfxHelpWindow_Impl() ...)
         // It should exist :-)
         xHelpContent = xHelpTask->findFrame(OUString("OFFICE_HELP"), FrameSearchFlag::CHILDREN);
     }
diff --git a/sfx2/source/dialog/backingcomp.cxx b/sfx2/source/dialog/backingcomp.cxx
index e79c35a..1e0e19b 100644
--- a/sfx2/source/dialog/backingcomp.cxx
+++ b/sfx2/source/dialog/backingcomp.cxx
@@ -529,7 +529,7 @@ void SAL_CALL BackingComp::restoreViewData( /*IN*/ const css::uno::Any& )
 
     @see    attachFrame()
 
-    @return The internaly saved frame reference.
+    @return The internally saved frame reference.
             Can be null, if attachFrame() was not called before.
  */
 
diff --git a/svx/source/inc/svxrectctaccessiblecontext.hxx b/svx/source/inc/svxrectctaccessiblecontext.hxx
index 7357b1c..69f46fe 100644
--- a/svx/source/inc/svxrectctaccessiblecontext.hxx
+++ b/svx/source/inc/svxrectctaccessiblecontext.hxx
@@ -236,7 +236,7 @@ protected:
     /** Selects a new child by index.
 
         <p>If the child was not selected before, the state of the child will
-        be updated. If the index is invalid, the index will internaly set to NOCHILDSELECTED</p>
+        be updated. If the index is invalid, the index will internally set to NOCHILDSELECTED</p>
 
         @param nIndexOfChild
             Index of the new child which should be selected.
@@ -247,7 +247,7 @@ public:
     /** Selects a new child by point.
 
         <p>If the child was not selected before, the state of the child will
-        be updated. If the point is not invalid, the index will internaly set to NOCHILDSELECTED</p>
+        be updated. If the point is not invalid, the index will internally set to NOCHILDSELECTED</p>
 
         @param eButton
             Button which belongs to the child which should be selected.
diff --git a/svx/source/unodraw/recoveryui.cxx b/svx/source/unodraw/recoveryui.cxx
index 0aa987d..4f4266d 100644
--- a/svx/source/unodraw/recoveryui.cxx
+++ b/svx/source/unodraw/recoveryui.cxx
@@ -167,7 +167,7 @@ css::uno::Any SAL_CALL RecoveryUI::dispatchWithReturnValue(const css::util::URL&
                                                    const css::uno::Sequence< css::beans::PropertyValue >& )
     throw(css::uno::RuntimeException)
 {
-    // Internaly we use VCL ... every call into vcl based code must
+    // Internally we use VCL ... every call into vcl based code must
     // be guarded by locking the global solar mutex.
     ::SolarMutexGuard aSolarLock;
 
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index f645d5c..e256938 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -5008,7 +5008,7 @@ void Window::ImplNotifyKeyMouseCommandEventListeners( NotifyEvent& rNEvt )
 
     // #82968# notify event listeners for mouse and key events separately and
     // not in PreNotify ( as for focus listeners )
-    // this allows for procesing those events internally first and pass it to
+    // this allows for processing those events internally first and pass it to
     // the toolkit later
 
     ImplDelData aDelData;


More information about the Libreoffice-commits mailing list
diff --git a/framework/inc/dispatch/closedispatcher.hxx b/framework/inc/dispatch/closedispatcher.hxx
index ba13b05..fff1ac4 100644
--- a/framework/inc/dispatch/closedispatcher.hxx
+++ b/framework/inc/dispatch/closedispatcher.hxx
@@ -96,7 +96,7 @@ class CloseDispatcher : // baseclasses ... order is necessary for right initiali
 
         //---------------------------------------
         /** @short  used for asynchronous callbacks within the main thread.
-            @descr  Internaly we work asynchronous. Because our callis
+            @descr  Internally we work asynchronous. Because our callis
                     are not aware, that her request can kill its own environment ... */
         ::vcl::EventPoster m_aAsyncCallback;
 
@@ -114,7 +114,7 @@ class CloseDispatcher : // baseclasses ... order is necessary for right initiali
         ListenerHash m_lStatusListener;
 
         //---------------------------------------
         /** @short  holded alive for internaly asynchronous operations! */
         css::uno::Reference< css::frame::XDispatchResultListener > m_xResultListener;
 
         SystemWindow* m_pSysWindow;
@@ -132,7 +132,7 @@ class CloseDispatcher : // baseclasses ... order is necessary for right initiali
 
             @param  rxContext
                     an un oservice manager, which is needed to create uno resource
-                    internaly.
+                    internally.
 
             @param  xFrame
                     the frame where the corresponding dispatch was started.
@@ -181,7 +181,7 @@ class CloseDispatcher : // baseclasses ... order is necessary for right initiali
         //---------------------------------------
         /** @short  a callback for asynchronous started operations.
 
-            @descr  As already mentione, we make internaly all operations
+            @descr  As already mentione, we make internally all operations
                     asynchronous. Otherwise our callis kill its own environment
                     during they call us ...
         */
@@ -114,7 +114,7 @@ class CloseDispatcher : // baseclasses ... order is necessary for right initiali
 
         //---------------------------------------
-        /** @short  holded alive for internaly asynchronous operations! */
+        /** @short  holded alive for internally asynchronous operations! */
         css::uno::Reference< css::frame::XDispatchResultListener > m_xResultListener;
 
diff --git a/framework/source/inc/accelerators/presethandler.hxx b/framework/source/inc/accelerators/presethandler.hxx
index ef8c28a..4589643 100644
--- a/framework/source/inc/accelerators/presethandler.hxx
+++ b/framework/source/inc/accelerators/presethandler.hxx
@@ -226,7 +226,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
                     cant have any special parameters!
 
             @param  xContext
-                    points to an uno service manager, which is used internaly
+                    points to an uno service manager, which is used internally
                     to create own needed uno resources.
          */
         PresetHandler(const css::uno::Reference< css::uno::XComponentContext >& xContext);
@@ -244,7 +244,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
         void forgetCachedStorages();
 
         //---------------------------------------
         /** @short  return access to the internaly used and cached root storage.
 
             @descr  These root storages are the base of all further opened
                     presets and targets. They are provided here only, to support
@@ -252,7 +252,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
 
                     getOrCreate...() - What does it mean?
                     Such root storage will be created one times only and
-                    cached then internaly till the last instance of such PresetHandler
+                    cached then internally till the last instance of such PresetHandler
                     dies.
 
             @return com::sun::star::embed::XStorage
@@ -312,7 +312,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
 
                     Localzation will be represented as directory structure
                     of provided presets. Means: you call us with a preset name "default";
-                    and we use e.g. "/en-US/default.xml" internaly.
+                    and we use e.g. "/en-US/default.xml" internally.
 
                     If no localization exists for this preset set, this class
                     will work in default mode - means "no locale" - automaticly.
@@ -244,7 +244,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
 
         //---------------------------------------
-        /** @short  return access to the internaly used and cached root storage.
+        /** @short  return access to the internally used and cached root storage.
 
             @descr  These root storages are the base of all further opened
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index 6ec5d43..7aa43e1 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -444,7 +444,7 @@ private:
 
     /** @descr  This member is used to prevent us against re-entrance problems.
                 A mutex cant help to prevent us from concurrent using of members
-                inside the same thread. But e.g. our internaly used stl structures
+                inside the same thread. But e.g. our internally used stl structures
                 are not threadsafe ... and furthermore they cant be used at the same time
                 for iteration and add/remove requests!
                 So we have to detect such states and ... show a warning.
@@ -539,7 +539,7 @@ public:
     // css.document.XEventListener
     /** @short  informs about created/opened documents.
 
-        @descr  Every new opened/created document will be saved internaly
+        @descr  Every new opened/created document will be saved internally
                 so it can be checked if its modified. This modified state
                 is used later to decide, if it must be saved or not.
 
@@ -1457,7 +1457,7 @@ void SAL_CALL AutoRecovery::dispatch(const css::util::URL&
     // This can be done immediately ... must not been done asynchronous.
     if ((eNewJob & AutoRecovery::E_DISABLE_AUTORECOVERY) == AutoRecovery::E_DISABLE_AUTORECOVERY)
     {
         // it's important to set a flag internaly, so AutoRecovery will be supressed - even if it's requested.
         m_eJob |= eNewJob;
         implts_stopTimer();
         implts_stopListening();
@@ -1821,7 +1821,7 @@ void SAL_CALL AutoRecovery::changesOccurred(const css::util::ChangesEvent& aEven
     } /* SAFE */
 
     // Note: This call stops the timer and starts it again.
     // But it checks the different timer states internaly and
     // may be supress the restart!
     implts_updateTimer();
 }
@@ -1457,7 +1457,7 @@ void SAL_CALL AutoRecovery::dispatch(const css::util::URL&
     if ((eNewJob & AutoRecovery::E_DISABLE_AUTORECOVERY) == AutoRecovery::E_DISABLE_AUTORECOVERY)
     {
-        // it's important to set a flag internaly, so AutoRecovery will be supressed - even if it's requested.
+        // it's important to set a flag internally, so AutoRecovery will be supressed - even if it's requested.
         m_eJob |= eNewJob;
         implts_stopTimer();
@@ -1821,7 +1821,7 @@ void SAL_CALL AutoRecovery::changesOccurred(const css::util::ChangesEvent& aEven
 
     // Note: This call stops the timer and starts it again.
-    // But it checks the different timer states internaly and
+    // But it checks the different timer states internally and
     // may be supress the restart!
     implts_updateTimer();